#### HEADER ================================================================
#
# [PURPOSE]
# Just testing a 1 and a 2 cpt model - only in NONMEM SAEM
#
# [AUTHOR]
# Henning Schmidt
#
# [INPUT]
# Data in ../Data/01_dataNLME_PK/dataNLME.csv
#
# [OUTPUT]
# Models in ../Models

## Preliminaries ====

rm(list = ls())
library(IQRtools)
IQRinitCompliance("SCRIPT_10_PK_base.R")



# -------------------------------------------------------------------------#
# MODELBASE01
# - Linear 1 compartmental distribution model
# - Additive-proportional error model
# - Log-normal IIV distribution for CL, Vc
# - Diagnonal random effect covariance matrix 
# - No covariates
# -------------------------------------------------------------------------#

model <- IQRmodel("Resources/model1cpt.txt")

dosing <- dosing_IQRest(
  INPUT1 = c(type="INFUSION")
)

data <- data_IQRest(
  datafile = "../Data/01_dataNLME_PK/dataNLME.csv",
  covNames = c("WT0","AGE0","ALB0","CK0","HT0"),
  catNames = c("SEXF","RACE")
)

modelSpec <- modelSpec_IQRest(
  POPvalues0      = c(CL=0.5,   Vc=3),
  IIVdistribution = c(CL="L",   Vc="L"),
  IIVestimate     = c(CL=1,     Vc=1),
  IIVvalues0      = c(CL=0.3,   Vc=0.3),
  
  errorModel = list(
    OUTPUT1 = c("absrel",0.2,0.3)
  )
)

est <- IQRnlmeEst(model,dosing,data,modelSpec)

# NONMEM SAEM
IQRnlmeProject(est,
               projectPath = "../Models/02_base_modeling/MODELBASE01",
               comment="1 cpt model",
               tool = "NONMEM",
               algOpt.NONMEM.METHOD = "SAEM")

run_IQRnlmeProject("../Models/02_base_modeling/MODELBASE01",ncores = 4)

# -------------------------------------------------------------------------#
# MODELBASE02
# - Linear 2 compartmental distribution model
# - Additive-proportional error model
# - Log-normal IIV distribution for CL, Vc, Q1, Vp1
# - Diagnonal random effect covariance matrix 
# - No covariates
# -------------------------------------------------------------------------#

model <- IQRmodel("Resources/model2cpt.txt")

dosing <- dosing_IQRest(
  INPUT1 = c(type="INFUSION")
)

data <- data_IQRest(
  datafile = "../Data/01_dataNLME_PK/dataNLME.csv",
  covNames = c("WT0","AGE0","ALB0","CK0","HT0"),
  catNames = c("SEXF","RACE")
)

modelSpec <- modelSpec_IQRest(
  POPvalues0      = c(CL=0.5,   Vc=3,   Q1=0.5,   Vp1=3),
  IIVdistribution = c(CL="L",   Vc="L", Q1="L",   Vp1="L"),
  IIVestimate     = c(CL=1,     Vc=1,   Q1=1,     Vp1=1),
  IIVvalues0      = c(CL=0.3,   Vc=0.3, Q1=0.3,   Vp1=0.3),

  errorModel = list(
    OUTPUT1 = c("absrel",0.2,0.3)
  )
)

est <- IQRnlmeEst(model,dosing,data,modelSpec)

# NONMEM SAEM
IQRnlmeProject(est,
               projectPath = "../Models/02_base_modeling/MODELBASE02",
               comment="2 cpt model",
               tool = "NONMEM",
               algOpt.NONMEM.METHOD = "SAEM")

run_IQRnlmeProject("../Models/02_base_modeling/MODELBASE02",ncores = 4)


# -------------------------------------------------------------------------#
# MODELBASE03
# - Linear 2 compartmental distribution model
# - Additive-proportional error model
# - Log-normal IIV distribution for CL, Vc, Q1, Vp1 
# - Diagnonal random effect covariance matrix - FIXED IIV on Q1
# - No covariates
# -------------------------------------------------------------------------#

model <- IQRmodel("Resources/model2cpt.txt")

dosing <- dosing_IQRest(
  INPUT1 = c(type="INFUSION")
)

data <- data_IQRest(
  datafile = "../Data/01_dataNLME_PK/dataNLME.csv",
  covNames = c("WT0","AGE0","ALB0","CK0","HT0"),
  catNames = c("SEXF","RACE")
)

modelSpec <- modelSpec_IQRest(
  POPvalues0      = c(CL=0.5,   Vc=3,   Q1=0.5,   Vp1=3),
  IIVdistribution = c(CL="L",   Vc="L", Q1="L",   Vp1="L"),
  IIVestimate     = c(CL=1,     Vc=1,   Q1=2,     Vp1=1),
  IIVvalues0      = c(CL=0.3,   Vc=0.3, Q1=0.1,   Vp1=0.3),
  
  errorModel = list(
    OUTPUT1 = c("absrel",0.2,0.3)
  )
)

est <- IQRnlmeEst(model,dosing,data,modelSpec)

# NONMEM SAEM
IQRnlmeProject(est,
               projectPath = "../Models/02_base_modeling/MODELBASE03",
               comment="2 cpt model - fixed IIV on Q1 (10%CV)",
               tool = "NONMEM",
               algOpt.NONMEM.METHOD = "SAEM")

run_IQRnlmeProject("../Models/02_base_modeling/MODELBASE03",ncores = 4)


# -------------------------------------------------------------------------#
# Generate a summary
# -------------------------------------------------------------------------#

pM <- as_IQRnlmeProjectMulti("../Models/02_base_modeling/")
summary(pM,pathname = "../Models/02_base_modeling/",FLAGremovePath = TRUE)

# -------------------------------------------------------------------------#
# Comparison table
# -------------------------------------------------------------------------#

pM <- as_IQRnlmeProjectMulti("../Models/02_base_modeling/")
names(pM) <- gsub("../Models/02_base_modeling//","",names(pM))
compareModels_IQRnlmeProjectMulti(pM,filename = "../Models/02_base_modeling/00_Comparison.txt")

# -------------------------------------------------------------------------#
# Select final base model
# -------------------------------------------------------------------------#

duplicate_IQRnlmeProject(projectSource = "../Models/02_base_modeling/MODELBASE03",
                         projectDestination = "../Output/FINALMODELS/01_BASEMODEL",
                         FLAGcopyData = TRUE)
